@@ -9,6 +9,17 @@ from rich.logging import RichHandler
 from rich import traceback
 from rich import print
 from pyfiglet import Figlet
+import pyfiglet
+
+log = None
+def print_title(title, logger_name):
+    global log
+    title = pyfiglet.figlet_format('DCCE CLI', font='slant')
+    print(f'[blue]{title}[/blue]')
+    FORMAT = "%(message)s"
+    logging.basicConfig(format=FORMAT, datefmt="[%X]", level="NOTSET", handlers=[RichHandler(rich_tracebacks=True, markup=True)])
+    traceback.install()
+    log = logging.getLogger("rich")
 
 class pyclibase(object):
     def __init__(self, args, name):
